@@ -1,5 +1,5 @@
 import re
-from typing import Literal, Optional
+from typing import Literal, Optional, Sequence
 from rapidata.api_client.models.root_filter import RootFilter
 from rapidata.api_client.models.filter import Filter
 from rapidata.api_client.models.query_model import QueryModel
@@ -15,7 +15,9 @@ from rapidata.api_client.models.submit_prompt_model_prompt_asset import (
 from rapidata.api_client.models.url_asset_input import UrlAssetInput
 from rapidata.api_client.models.file_asset_model import FileAssetModel
 from rapidata.api_client.models.source_url_metadata_model import SourceUrlMetadataModel
-
+from rapidata.api_client.models.and_user_filter_model_filters_inner import (
+    AndUserFilterModelFiltersInner,
+)
 
 from rapidata.rapidata_client.benchmark.participant._participant import (
     BenchmarkParticipant,
@@ -28,6 +30,8 @@ from rapidata.rapidata_client.benchmark.leaderboard.rapidata_leaderboard import
 )
 from rapidata.rapidata_client.datapoints.assets import MediaAsset
 from rapidata.rapidata_client.benchmark._detail_mapper import DetailMapper
+from rapidata.rapidata_client.filter import RapidataFilter
+from rapidata.rapidata_client.settings import RapidataSetting
 
 
 class RapidataBenchmark:
@@ -260,6 +264,9 @@ class RapidataBenchmark:
         inverse_ranking: bool = False,
         level_of_detail: Literal["low", "medium", "high", "very high"] = "low",
         min_responses_per_matchup: int = 3,
+        validation_set_id: str | None = None,
+        filters: Sequence[RapidataFilter] = [],
+        settings: Sequence[RapidataSetting] = [],
     ) -> RapidataLeaderboard:
         """
         Creates a new leaderboard for the benchmark.
@@ -272,6 +279,9 @@ class RapidataBenchmark:
             inverse_ranking: Whether to inverse the ranking of the leaderboard. (if the question is inversed, e.g. "Which video is worse?")
             level_of_detail: The level of detail of the leaderboard. This will effect how many comparisons are done per model evaluation. (default: "low")
             min_responses_per_matchup: The minimum number of responses required to be considered for the leaderboard. (default: 3)
+            validation_set_id: The id of the validation set that should be attached to the leaderboard. (default: None)
+            filters: The filters that should be applied to the leaderboard. Will determine who can solve answer in the leaderboard. (default: [])
+            settings: The settings that should be applied to the leaderboard. Will determine the behavior of the tasks on the leaderboard. (default: [])
         """
         if not isinstance(min_responses_per_matchup, int):
             raise ValueError("Min responses per matchup must be an integer")
@@ -289,6 +299,20 @@ class RapidataBenchmark:
                 isInversed=inverse_ranking,
                 minResponses=min_responses_per_matchup,
                 responseBudget=DetailMapper.get_budget(level_of_detail),
+                validationSetId=validation_set_id,
+                filters=(
+                    [
+                        AndUserFilterModelFiltersInner(filter._to_model())
+                        for filter in filters
+                    ]
+                    if filters
+                    else None
+                ),
+                featureFlags=(
+                    [setting._to_feature_flag() for setting in settings]
+                    if settings
+                    else None
+                ),
             )
         )
 
